.. rst-class:: detail

ExternalAxes
=======================

.. currentmodule:: compas_rrc

.. autoclass:: ExternalAxes

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~ExternalAxes.__init__
    
    